---------------------------------------------------------------------------
-- This VHDL file was developed by Daniel Llamocca (2013).  It may be
-- freely copied and/or distributed at no cost.  Any persons using this
-- file for any purpose do so at their own risk, and are responsible for
-- the results of such use.  Daniel Llamocca does not guarantee that
-- this file is complete, correct, or fit for any particular purpose.
-- NO WARRANTY OF ANY KIND IS EXPRESSED OR IMPLIED.  This notice must
-- accompany any copy of this file.
--------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
 
-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--USE ieee.numeric_std.ALL;
 
ENTITY tb_lights_pattern IS
END tb_lights_pattern;
 
ARCHITECTURE behavior OF tb_lights_pattern IS 
 
    -- Component Declaration for the Unit Under Test (UUT)
 
    COMPONENT lights_pattern
    PORT(
         resetn : IN  std_logic;
         clock : IN  std_logic;
         stop : IN  std_logic;
         x : IN  std_logic_vector(1 downto 0);
         sel : IN  std_logic_vector(1 downto 0);
         segs : OUT  std_logic_vector(6 downto 0);
         EN : OUT  std_logic_vector(3 downto 0)
        );
    END COMPONENT;
    

   --Inputs
   signal resetn : std_logic := '0';
   signal clock : std_logic := '0';
   signal stop : std_logic := '0';
   signal x : std_logic_vector(1 downto 0) := (others => '0');
   signal sel : std_logic_vector(1 downto 0) := (others => '0');

 	--Outputs
   signal segs : std_logic_vector(6 downto 0);
   signal EN : std_logic_vector(3 downto 0);

   -- Clock period definitions
   constant clock_period : time := 10 ns;
 
BEGIN
 
	-- Instantiate the Unit Under Test (UUT)
   uut: lights_pattern PORT MAP (
          resetn => resetn,
          clock => clock,
          stop => stop,
          x => x,
          sel => sel,
          segs => segs,
          EN => EN
        );

   -- Clock process definitions
   clock_process :process
   begin
		clock <= '0';
		wait for clock_period/2;
		clock <= '1';
		wait for clock_period/2;
   end process;
 

   -- Stimulus process
   stim_proc: process
   begin		
      -- hold reset state for 100 ns.
      resetn <= '0'; wait for 100 ns;	
		resetn <= '1';
		x <= "00"; sel <= "00"; stop <= '0';
      wait for clock_period*10;
		x <= "00"; sel <= "01"; stop <= '0';
      wait for clock_period*10;
		x <= "00"; sel <= "10"; stop <= '0';
      wait for clock_period*10;
		x <= "00"; sel <= "11"; stop <= '0';
      wait for clock_period*10;
		x <= "00"; sel <= "00"; stop <= '0';
      wait for clock_period*3;
		stop <= '1'; wait for clock_period*2;
		stop <= '0';     

      wait;
   end process;

END;
